@@ -1,3 +1,4 @@
+from re import X
 import strax
 import numpy as np
 import numba
@@ -26,10 +27,6 @@ export, __all__ = strax.exporter()
                  help='Extend events this many ns to the right from each '
                       'triggering peak.',
                  ),
-    strax.Option(name='electron_drift_velocity', infer_type=False,
-                 default=("electron_drift_velocity", "ONLINE", True),
-                 help='Vertical electron drift velocity in cm/ns (1e4 m/ms)',
-                 ),
     strax.Option(name='max_drift_length',
                  default=straxen.tpc_z, type=(int, float),
                  help='Total length of the TPC from the bottom of gate to the '
@@ -48,9 +45,9 @@ class Events(strax.OverlapWindowPlugin):
     which satisfies certain conditions:
         1. The triggering peak must have a certain area.
         2. The triggering peak must have less than
-        "trigger_max_competing" peaks. (A competing peak must have a
-        certain area fraction of the triggering peak and must be in a
-        window close to the main peak)
+           "trigger_max_competing" peaks. (A competing peak must have a
+           certain area fraction of the triggering peak and must be in a
+           window close to the main peak)
 
     Note:
         The time range which defines an event gets chopped at the chunk
@@ -62,6 +59,14 @@ class Events(strax.OverlapWindowPlugin):
     __version__ = '0.1.0'
     save_when = strax.SaveWhen.NEVER
 
+    electron_drift_velocity = straxen.URLConfig(
+        default='cmt://'
+                'electron_drift_velocity'
+                '?version=ONLINE&run_id=plugin.run_id',
+        cache=True,
+        help='Vertical electron drift velocity in cm/ns (1e4 m/ms)'
+    )
+
     dtype = [
         ('event_number', np.int64, 'Event number in this dataset'),
         ('time', np.int64, 'Event start time in ns since the unix epoch'),
@@ -70,10 +75,7 @@ class Events(strax.OverlapWindowPlugin):
     events_seen = 0
 
     def setup(self):
-        electron_drift_velocity = get_correction_from_cmt(
-            self.run_id,
-            self.config['electron_drift_velocity'])
-        self.drift_time_max = int(self.config['max_drift_length'] / electron_drift_velocity)
+        self.drift_time_max = int(self.config['max_drift_length'] / self.electron_drift_velocity)
         # Left_extension and right_extension should be computed in setup to be
         # reflected in cutax too.
         self.left_extension = self.config['left_event_extension'] + self.drift_time_max
@@ -128,21 +130,32 @@ class Events(strax.OverlapWindowPlugin):
         name='force_main_before_alt', default=False, infer_type=False,
         help="Make the alternate S1 (and likewise S2) the main S1 if "
              "occurs before the main S1."),
+    strax.Option(
+        name='force_alt_s2_in_max_drift_time', default=True, infer_type=False,
+        help="Make sure alt_s2 is in max drift time starting from main S1"),
     strax.Option(
         name='event_s1_min_coincidence',
         default=2, infer_type=False,
         help="Event level S1 min coincidence. Should be >= s1_min_coincidence "
              "in the peaklet classification"),
+    strax.Option(
+        name='max_drift_length',
+        default=straxen.tpc_z, infer_type=False,
+        help='Total length of the TPC from the bottom of gate to the '
+             'top of cathode wires [cm]',),
 )
 class EventBasics(strax.Plugin):
     """
     Computes the basic properties of the main/alternative S1/S2 within
     an event.
 
-    The main S2 and alternative S2 are given by the largest two S2-Peaks
-    within the event. By default this is also true for S1.
+    The main S1 and alternative S1 are given by the largest two S1-Peaks
+    within the event.
+    The main S2 is given by the largest S2-Peak within the event, while
+    alternative S2 is selected as the largest S2 other than main S2
+    in the time window [main S1 time, main S1 time + max drift time].
     """
-    __version__ = '1.2.1'
+    __version__ = '1.3.1'
 
     depends_on = ('events',
                   'peak_basics',
@@ -152,6 +165,14 @@ class EventBasics(strax.Plugin):
     data_kind = 'events'
     loop_over = 'events'
 
+    electron_drift_velocity = straxen.URLConfig(
+        default='cmt://'
+                'electron_drift_velocity'
+                '?version=ONLINE&run_id=plugin.run_id',
+        cache=True,
+        help='Vertical electron drift velocity in cm/ns (1e4 m/ms)'
+    )
+
     def infer_dtype(self):
         # Basic event properties
         self._set_posrec_save()
@@ -196,6 +217,7 @@ class EventBasics(strax.Plugin):
             ('endtime',           np.int64,   'end time since unix epoch [ns]'),
             ('area',              np.float32, 'area, uncorrected [PE]'),
             ('n_channels',        np.int16,   'count of contributing PMTs'),
+            ('n_hits',            np.int16,   'count of hits contributing at least one sample to the peak'),
             ('n_competing',       np.int32,   'number of competing peaks'),
             ('max_pmt',           np.int16,   'PMT number which contributes the most PE'),
             ('max_pmt_area',      np.float32, 'area in the largest-contributing PMT (PE)'),
@@ -207,6 +229,9 @@ class EventBasics(strax.Plugin):
             ('n_saturated_channels',      np.int16, 'Total number of saturated channels'),
         )
 
+    def setup(self):
+        self.drift_time_max = int(self.config['max_drift_length'] / self.electron_drift_velocity)
+
     @staticmethod
     def _get_si_dtypes(peak_properties):
         """Get properties for S1/S2 from peaks directly"""
@@ -305,12 +330,8 @@ class EventBasics(strax.Plugin):
     def fill_result_i(self, event, peaks):
         """For a single event with the result_buffer"""
         # Consider S2s first, then S1s (to enable allow_posts2_s1s = False)
-        largest_s2s, s2_idx = self.get_largest_sx_peaks(peaks, s_i=2)
-
-        if self.config['force_main_before_alt']:
-            s2_order = np.argsort(largest_s2s['time'])
-            largest_s2s = largest_s2s[s2_order]
-            s2_idx = s2_idx[s2_order]
+        # number_of_peaks=0 selects all available s2 and sort by area
+        largest_s2s, s2_idx = self.get_largest_sx_peaks(peaks, s_i=2, number_of_peaks=0)
 
         if not self.config['allow_posts2_s1s'] and len(largest_s2s):
             s1_latest_time = largest_s2s[0]['time']
@@ -323,6 +344,21 @@ class EventBasics(strax.Plugin):
             s1_before_time=s1_latest_time,
             s1_min_coincidence=self.config['event_s1_min_coincidence'])
 
+        if self.config['force_alt_s2_in_max_drift_time']:
+            s2_idx, largest_s2s = self.find_main_alt_s2(largest_s1s,
+                                                        s2_idx,
+                                                        largest_s2s,
+                                                        self.drift_time_max,
+                                                        )
+        else:
+            # Select only the largest two S2s
+            largest_s2s, s2_idx = largest_s2s[0:2], s2_idx[0:2]
+
+        if self.config['force_main_before_alt']:
+            s2_order = np.argsort(largest_s2s['time'])
+            largest_s2s = largest_s2s[s2_order]
+            s2_idx = s2_idx[s2_order]
+
         self.set_sx_index(event, s1_idx, s2_idx)
         self.set_event_properties(event, largest_s1s, largest_s2s, peaks)
 
@@ -341,6 +377,22 @@ class EventBasics(strax.Plugin):
                                                    field_names,
                                                    peak_properties_to_save)
 
+    @staticmethod
+    @numba.njit
+    def find_main_alt_s2(largest_s1s, s2_idx, largest_s2s, drift_time_max):
+        """Require alt_s2 happens between main S1 and maximum drift time"""
+        if len(largest_s1s) > 0 and len(largest_s2s) > 1:
+            # If there is a valid s1-s2 pair and has a second s2, then check alt s2 validity
+            s2_after_s1 = largest_s2s['center_time'] > largest_s1s[0]['center_time']
+            s2_before_max_drift_time = (largest_s2s['center_time']
+                                        - largest_s1s[0]['center_time']) < 1.01 * drift_time_max
+            mask = s2_after_s1 & s2_before_max_drift_time
+            # The selection avoids main_S2
+            mask[0] = True
+            # Take main and the largest valid alt_S2
+            s2_idx, largest_s2s = s2_idx[mask][:2], largest_s2s[mask][:2]
+        return s2_idx, largest_s2s
+
     @staticmethod
     @numba.njit
     def set_event_properties(result, largest_s1s, largest_s2s, peaks):
@@ -427,16 +479,6 @@ class EventBasics(strax.Plugin):
 
 @export
 @strax.takes_config(
-    strax.Option(
-        name='electron_drift_velocity', infer_type=False,
-        help='Vertical electron drift velocity in cm/ns (1e4 m/ms)',
-        default=("electron_drift_velocity", "ONLINE", True)
-    ),
-    strax.Option(
-        name='electron_drift_time_gate', infer_type=False,
-        help='Electron drift time from the gate in ns',
-        default=("electron_drift_time_gate", "ONLINE", True)
-    ),
     strax.Option(
         name='fdc_map', infer_type=False,
         help='3D field distortion correction map path',
@@ -466,6 +508,21 @@ class EventPositions(strax.Plugin):
         help="default reconstruction algorithm that provides (x,y)"
     )
 
+    electron_drift_velocity = straxen.URLConfig(
+        default='cmt://'
+                'electron_drift_velocity'
+                '?version=ONLINE&run_id=plugin.run_id',
+        cache=True,
+        help='Vertical electron drift velocity in cm/ns (1e4 m/ms)'
+    )
+
+    electron_drift_time_gate = straxen.URLConfig(
+        default='cmt://'
+                'electron_drift_time_gate'
+                '?version=ONLINE&run_id=plugin.run_id',
+        help='Electron drift time from the gate in ns',
+        cache=True)
+
     dtype = [
         ('x', np.float32,
          'Interaction x-position, field-distortion corrected (cm)'),
@@ -488,12 +545,6 @@ class EventPositions(strax.Plugin):
             ] + strax.time_fields
 
     def setup(self):
-
-        self.electron_drift_velocity = get_correction_from_cmt(
-            self.run_id, self.config['electron_drift_velocity'])
-        self.electron_drift_time_gate = get_correction_from_cmt(
-            self.run_id, self.config['electron_drift_time_gate'])
-        
         if isinstance(self.config['fdc_map'], str):
             self.map = InterpolatingMap(
                 get_resource(self.config['fdc_map'], fmt='binary'))
@@ -552,60 +603,6 @@ class EventPositions(strax.Plugin):
         return result
 
 
-@export
-class EventInfoVetos(strax.Plugin):
-    """
-    Plugin which combines event_info with the tagged peaks information
-    from muon- and neutron-veto.
-    """
-    __version__ = '0.0.0'
-    depends_on = ('event_basics', 'peak_veto_tags')
-    provides = 'events_tagged'
-    save_when = strax.SaveWhen.TARGET
-
-    def infer_dtype(self):
-        dtype = []
-        dtype += strax.time_fields
-
-        for s_i in [1, 2]:
-            for peak_type in ['', 'alt_']:
-                dtype += [((f"Veto tag for {peak_type}S{s_i}: unatagged: 0, nveto: 1, mveto: 2, both: 3",
-                            f"{peak_type}s{s_i}_veto_tag"), np.int8),
-                          ((f"Time to closest veto interval for {peak_type}s{s_i}",
-                            f"{peak_type}s{s_i}_dt_veto"), np.int64),
-                          ]
-        dtype += [(('Number of peaks tagged by NV/MV inside event', 'n_tagged_peaks'), np.int16)]
-        return dtype
-
-    def compute(self, events, peaks):
-        split_tags = strax.split_by_containment(peaks, events)
-        result = np.zeros(len(events), self.dtype)
-        result['time'] = events['time']
-        result['endtime'] = events['endtime']
-        get_veto_tags(events, split_tags, result)
-
-        return result
-
-
-def get_veto_tags(events, split_tags, result):
-    """
-    Loops over events and tag main/alt S1/2 according to peak tag.
-
-    :param events: Event_info data type to be tagged.
-    :param split_tags: Tags split by events.
-    """
-    for tags_i, event_i, result_i in zip(split_tags, events, result):
-        result_i['n_tagged_peaks'] = np.sum(tags_i['veto_tag'] > 0)
-        for s_i in [1, 2]:
-            for peak_type in ['', 'alt_']:
-                if event_i[f'{peak_type}s{s_i}_index'] == -1:
-                    continue
-
-                index = event_i[f'{peak_type}s{s_i}_index']
-                result_i[f'{peak_type}s{s_i}_veto_tag'] = tags_i[index]['veto_tag']
-                result_i[f'{peak_type}s{s_i}_dt_veto'] = tags_i[index]['time_to_closest_veto']
-
-
 @export
 class CorrectedAreas(strax.Plugin):
     """
@@ -623,7 +620,7 @@ class CorrectedAreas(strax.Plugin):
         cs2_top and cs2_bottom are corrected by the corresponding maps,
         and cs2 is the sum of the two.
     """
-    __version__ = '0.2.0'
+    __version__ = '0.2.1'
 
     depends_on = ['event_basics', 'event_positions']
 
@@ -661,17 +658,25 @@ class CorrectedAreas(strax.Plugin):
         help='Actual SE gain for a given run (allows for time dependence)')
 
     # relative extraction efficiency which can change with time and modeled by CMT.
-    # defaults to no correction
     rel_extraction_eff = straxen.URLConfig(
-        default=1.0,
+        default='cmt://rel_extraction_eff?version=ONLINE&run_id=plugin.run_id',
         help='Relative extraction efficiency for this run (allows for time dependence)')
 
+    # relative light yield
+    # defaults to no correction
+    rel_light_yield = straxen.URLConfig(
+        default='cmt://relative_light_yield?version=ONLINE&run_id=plugin.run_id',
+        help='Relative light yield (allows for time dependence)'
+    )
+
     def infer_dtype(self):
         dtype = []
         dtype += strax.time_fields
 
         for peak_type, peak_name in zip(['', 'alt_'], ['main', 'alternate']):
             dtype += [(f'{peak_type}cs1', np.float32, f'Corrected area of {peak_name} S1 [PE]'),
+                      (f'{peak_type}cs1_wo_timecorr', np.float32,
+                       f'Corrected area of {peak_name} S1 [PE] before time-dep LY correction'),
                       (f'{peak_type}cs2_wo_elifecorr', np.float32,
                        f'Corrected area of {peak_name} S2 before elife correction '
                        f'(s2 xy correction + SEG/EE correction applied) [PE]'),
@@ -697,7 +702,8 @@ class CorrectedAreas(strax.Plugin):
         event_positions = np.vstack([events['x'], events['y'], events['z']]).T
 
         for peak_type in ["", "alt_"]:
-            result[f"{peak_type}cs1"] = events[f'{peak_type}s1_area'] / self.s1_xyz_map(event_positions)
+            result[f"{peak_type}cs1_wo_timecorr"] = events[f'{peak_type}s1_area'] / self.s1_xyz_map(event_positions)
+            result[f"{peak_type}cs1"] = result[f"{peak_type}cs1_wo_timecorr"] / self.rel_light_yield
 
         # s2 corrections
         # S2 top and bottom are corrected separately, and cS2 total is the sum of the two
@@ -789,56 +795,124 @@ class EnergyEstimates(strax.Plugin):
 @export
 class EventShadow(strax.Plugin):
     """
-    This plugin can calculate shadow at event level.
-    It depends on peak-level shadow.
-    The event-level shadow is its first S2 peak's shadow.
-    If no S2 peaks, the event shadow will be nan.
-    It also gives the position infomation of the previous S2s
-    and main peaks' shadow.
+    This plugin can calculate shadow for main S1 and main S2 in events.
+    It also gives the position information of the previous peaks.
+    References:
+        * v0.1.3 reference: xenon:xenonnt:ac:prediction:shadow_ambience
     """
-    __version__ = '0.0.8'
+    __version__ = '0.1.3'
     depends_on = ('event_basics', 'peak_basics', 'peak_shadow')
     provides = 'event_shadow'
     save_when = strax.SaveWhen.EXPLICIT
 
     def infer_dtype(self):
-        dtype = [('s1_shadow', np.float32, 'main s1 shadow [PE/ns]'),
-                 ('s2_shadow', np.float32, 'main s2 shadow [PE/ns]'),
-                 ('shadow', np.float32, 'shadow of event [PE/ns]'),
-                 ('pre_s2_area', np.float32, 'previous s2 area [PE]'),
-                 ('shadow_dt', np.int64, 'time difference to the previous s2 [ns]'),
-                 ('shadow_index', np.int32, 'max shadow peak index in event'),
-                 ('pre_s2_x', np.float32, 'x of previous s2 peak causing shadow [cm]'),
-                 ('pre_s2_y', np.float32, 'y of previous s2 peak causing shadow [cm]'),
-                 ('shadow_distance', np.float32, 'distance to the s2 peak with max shadow [cm]')]
+        dtype = []
+        for main_peak, main_peak_desc in zip(['s1_', 's2_'], ['main S1', 'main S2']):
+            # previous S1 can only cast time shadow, previous S2 can cast both time & position shadow
+            for key in ['s1_time_shadow', 's2_time_shadow', 's2_position_shadow']:
+                type_str, tp_desc, _ = key.split('_')
+                dtype.append(((f'largest {tp_desc} shadow casting from previous {type_str} to {main_peak_desc} [PE/ns]', 
+                               f'{main_peak}shadow_{key}'), np.float32))
+                dtype.append(((f'time difference from the previous {type_str} casting largest {tp_desc} shadow to {main_peak_desc} [ns]', 
+                               f'{main_peak}dt_{key}'), np.int64))
+                # Only previous S2 peaks have (x,y)
+                if 's2' in key:
+                    dtype.append(((f'x of previous s2 peak casting largest {tp_desc} shadow on {main_peak_desc} [cm]', 
+                                   f'{main_peak}x_{key}'), np.float32))
+                    dtype.append(((f'y of previous s2 peak casting largest {tp_desc} shadow on {main_peak_desc} [cm]', 
+                                   f'{main_peak}y_{key}'), np.float32))
+                # Only time shadow gives the nearest large peak
+                if 'time' in key:
+                    dtype.append(((f'time difference from the nearest previous large {type_str} to {main_peak_desc} [ns]', 
+                                   f'{main_peak}nearest_dt_{type_str}'), np.int64))
+            # Also record the PDF of HalfCauchy when calculating S2 position shadow
+            dtype.append(((f'PDF describing correlation between previous s2 and {main_peak_desc}', 
+                           f'{main_peak}pdf_s2_position_shadow'), np.float32))
+        dtype += strax.time_fields
+        return dtype
+
+    @staticmethod
+    def set_nan_defaults(result):
+        """
+        When constructing the dtype, take extra care to set values to
+        np.Nan / -1 (for ints) as 0 might have a meaning
+        """
+        for field in result.dtype.names:
+            if np.issubdtype(result.dtype[field], np.integer):
+                result[field][:] = -1
+            else:
+                result[field][:] = np.nan
+
+    def compute(self, events, peaks):
+        split_peaks = strax.split_by_containment(peaks, events)
+        result = np.zeros(len(events), self.dtype)
+
+        self.set_nan_defaults(result)
+
+        # 1. Assign peaks features to main S1 and main S2 in the event
+        for event_i, (event, sp) in enumerate(zip(events, split_peaks)):
+            res_i = result[event_i]
+            # Fetch the features of main S1 and main S2
+            for idx, main_peak in zip([event['s1_index'], event['s2_index']], ['s1_', 's2_']):
+                if idx >= 0:
+                    for key in ['s1_time_shadow', 's2_time_shadow', 's2_position_shadow']:
+                        type_str = key.split('_')[0]
+                        res_i[f'{main_peak}shadow_{key}'] = sp[f'shadow_{key}'][idx]
+                        res_i[f'{main_peak}dt_{key}'] = sp[f'dt_{key}'][idx]
+                    if 'time' in key:
+                        res_i[f'{main_peak}nearest_dt_{key}'] = sp[f'nearest_dt_{type_str}'][idx]
+                    if 's2' in key:
+                        res_i[f'{main_peak}x_{key}'] = sp[f'x_{key}'][idx]
+                        res_i[f'{main_peak}y_{key}'] = sp[f'y_{key}'][idx]
+                    # Record the PDF of HalfCauchy
+                    res_i[f'{main_peak}pdf_s2_position_shadow'] = sp['pdf_s2_position_shadow'][idx]
+
+        # 2. Set time and endtime for events
+        result['time'] = events['time']
+        result['endtime'] = strax.endtime(events)
+        return result
+
+
+@export
+class EventAmbience(strax.Plugin):
+    """
+    Save Ambience of the main S1 and main S2 in the event.
+    References:
+        * v0.0.4 reference: xenon:xenonnt:ac:prediction:shadow_ambience
+    """
+    __version__ = '0.0.4'
+    depends_on = ('event_basics', 'peak_basics', 'peak_ambience')
+    provides = 'event_ambience'
+    save_when = strax.SaveWhen.EXPLICIT
+
+    @property
+    def origin_dtype(self):
+        return ['lh_before', 's0_before', 's1_before', 's2_before', 's2_near']
+
+    def infer_dtype(self):
+        dtype = []
+        for ambience in self.origin_dtype:
+            dtype.append(((f"Number of  {' '.join(ambience.split('_'))} main S1", 
+                           f's1_n_{ambience}'), np.int16))
+            dtype.append(((f"Number of  {' '.join(ambience.split('_'))} main S2", 
+                           f's2_n_{ambience}'), np.int16))
         dtype += strax.time_fields
         return dtype
 
     def compute(self, events, peaks):
         split_peaks = strax.split_by_containment(peaks, events)
-        res = np.zeros(len(events), self.dtype)
 
-        res['shadow_index'] = -1
-        res['pre_s2_x'] = np.nan
-        res['pre_s2_y'] = np.nan
+        # 1. Initialization, ambience is set to be the lowest possible value
+        result = np.zeros(len(events), self.dtype)
 
+        # 2. Assign peaks features to main S1, main S2 in the event
         for event_i, (event, sp) in enumerate(zip(events, split_peaks)):
-            if event['s1_index'] >= 0:
-                res['s1_shadow'][event_i] = sp['shadow'][event['s1_index']]
-            if event['s2_index'] >= 0:
-                res['s2_shadow'][event_i] = sp['shadow'][event['s2_index']]
-            if (sp['type'] == 2).sum() > 0:
-                # Define event shadow as the first S2 peak shadow
-                first_s2_index = np.argwhere(sp['type'] == 2)[0]
-                res['shadow_index'][event_i] = first_s2_index
-                res['shadow'][event_i] = sp['shadow'][first_s2_index]
-                res['pre_s2_area'][event_i] = sp['pre_s2_area'][first_s2_index]
-                res['shadow_dt'][event_i] = sp['shadow_dt'][first_s2_index]
-                res['pre_s2_x'][event_i] = sp['pre_s2_x'][first_s2_index]
-                res['pre_s2_y'][event_i] = sp['pre_s2_y'][first_s2_index]
-        res['shadow_distance'] = ((res['pre_s2_x'] - events['s2_x'])**2 +
-                                  (res['pre_s2_y'] - events['s2_y'])**2
-                                  )**0.5
-        res['time'] = events['time']
-        res['endtime'] = strax.endtime(events)
-        return res
+            for idx, main_peak in zip([event['s1_index'], event['s2_index']], ['s1_', 's2_']):
+                if idx >= 0:
+                    for ambience in self.origin_dtype:
+                        result[f'{main_peak}n_{ambience}'][event_i] = sp[f'n_{ambience}'][idx]
+
+        # 3. Set time and endtime for events
+        result['time'] = events['time']
+        result['endtime'] = strax.endtime(events)
+        return result
