@@ -8,6 +8,7 @@ import tempfile
 import os
 import unittest
 
+
 ##
 # XENONnT
 ##
@@ -18,6 +19,26 @@ def test_xenonnt_online():
     st.search_field('time')
 
 
+@unittest.skipIf(not straxen.utilix_is_configured(), "No db access, cannot test!")
+def test_xenonnt_online_with_online_frontend():
+    st = xenonnt_online(include_online_monitor=True)
+    for sf in st.storage:
+        if 'OnlineMonitor' == sf.__class__.__name__:
+            break
+    else:
+        raise ValueError(f"Online monitor not in {st.storage}")
+
+
+@unittest.skipIf(not straxen.utilix_is_configured(), "No db access, cannot test!")
+def test_xenonnt_online_rucio_local():
+    st = xenonnt_online(include_rucio_local=True, _rucio_local_path='./test')
+    for sf in st.storage:
+        if 'RucioLocalFrontend' == sf.__class__.__name__:
+            break
+    else:
+        raise ValueError(f"Online monitor not in {st.storage}")
+
+
 @unittest.skipIf(not straxen.utilix_is_configured(), "No db access, cannot test!")
 def test_xennonnt():
     st = xenonnt(_database_init=False)
@@ -118,6 +139,7 @@ class TestSimContextNT(unittest.TestCase):
         kwargs.setdefault('cmt_version', 'global_ONLINE')
         return straxen.contexts.xenonnt_simulation(*args, **kwargs)
 
+    @unittest.skipIf(not straxen.utilix_is_configured(), "No db access, cannot test!")
     def test_nt_sim_context_main(self):
         st = self.context(cmt_run_id_sim='008000')
         st.search_field('time')
@@ -161,3 +183,9 @@ class TestSimContextNT(unittest.TestCase):
 def test_sim_context():
     st = straxen.contexts.xenon1t_simulation()
     st.search_field('time')
+
+
+@unittest.skipIf(not straxen.utilix_is_configured(), "No db access, cannot test!")
+def test_offline():
+    st = xenonnt('latest')
+    st.provided_dtypes()
